@@ -5,7 +5,7 @@ import plotly.express as px
 from bender.evaluator.interface import Evaluator
 from bender.exporter.exporter import Exporter
 from bender.split_strategy.split_strategy import TrainingDataSet
-from bender.trainer.model_trainer import TrainedClassificationModel, TrainedModel
+from bender.trained_model.interface import TrainedClassificationModel, TrainedModel
 
 logger = logging.getLogger(__name__)
 
